/*
 * This is a local header where we stuff things when we're compiling
 * standalone (i.e., outside of the kernel).
 */

#ifdef ENABLE_SERIAL_PCI
#include <linux/pci.h>
#endif

#include "serial.h"
#include "serialP.h"
#include "serial_reg.h"
#ifdef __powerpc
#include "ppc_serial.h"
#endif
#ifdef __i386__
#include "i386_serial.h"
#endif

#define LOCAL_VERSTRING ".SA"	/* This is a stand-alone distribution */

/*
 * Some PCI identifiers which might not be in pci.h
 */

#ifndef PCI_VENDOR_ID_V3
#define PCI_VENDOR_ID_V3		0x11b0
#define PCI_DEVICE_ID_V3_V960		0x0001
#define PCI_DEVICE_ID_V3_V350		0x0001
#define PCI_DEVICE_ID_V3_V960V2		0x0002
#define PCI_DEVICE_ID_V3_V350V2		0x0002
#endif

#ifndef PCI_VENDOR_ID_SEALEVEL
#define PCI_VENDOR_ID_SEALEVEL		0x135e
#define PCI_DEVICE_ID_SEALEVEL_U530	0x7101
#define PCI_DEVICE_ID_SEALEVEL_UCOMM2	0x7201
#define PCI_DEVICE_ID_SEALEVEL_UCOMM422	0x7402
#define PCI_DEVICE_ID_SEALEVEL_UCOMM232	0x7202
#define PCI_DEVICE_ID_SEALEVEL_COMM4	0x7401
#define PCI_DEVICE_ID_SEALEVEL_COMM8	0x7801
#endif
	
#ifndef PCI_SUBVENDOR_ID_CONNECT_TECH
#define PCI_SUBVENDOR_ID_CONNECT_TECH			0x12c4
#define PCI_SUBDEVICE_ID_CONNECT_TECH_BH8_232		0x0001
#define PCI_SUBDEVICE_ID_CONNECT_TECH_BH4_232		0x0002
#define PCI_SUBDEVICE_ID_CONNECT_TECH_BH2_232		0x0003
#define PCI_SUBDEVICE_ID_CONNECT_TECH_BH8_485		0x0004
#define PCI_SUBDEVICE_ID_CONNECT_TECH_BH8_485_4_4	0x0005
#define PCI_SUBDEVICE_ID_CONNECT_TECH_BH4_485		0x0006
#define PCI_SUBDEVICE_ID_CONNECT_TECH_BH4_485_2_2	0x0007
#define PCI_SUBDEVICE_ID_CONNECT_TECH_BH2_485		0x0008
#endif

#ifndef PCI_SUBVENDOR_ID_KEYSPAN
#define PCI_SUBVENDOR_ID_KEYSPAN 			0x11a9
#define PCI_SUBDEVICE_ID_KEYSPAN_SX2			0x5334
#endif

#ifndef PCI_DEVICE_ID_PLX_GTEK_SERIAL2
#define PCI_DEVICE_ID_PLX_GTEK_SERIAL2	0xa001
#endif

#ifndef PCI_DEVICE_ID_PLX_SPCOM200
#define PCI_DEVICE_ID_PLX_SPCOM200 0x1103
#endif

#ifndef PCI_VENDOR_ID_PANACOM
#define PCI_VENDOR_ID_PANACOM             0x14d4
#define PCI_DEVICE_ID_PANACOM_QUADMODEM   0x0400
#define PCI_DEVICE_ID_PANACOM_DUALMODEM   0x0402
#endif

#ifndef PCI_SUBVENDOR_ID_CHASE_PCIFAST
#define PCI_SUBVENDOR_ID_CHASE_PCIFAST		0x12E0
#define PCI_SUBDEVICE_ID_CHASE_PCIFAST4		0x0031
#define PCI_SUBDEVICE_ID_CHASE_PCIFAST8		0x0021
#define PCI_SUBDEVICE_ID_CHASE_PCIFAST16	0x0011
#define PCI_SUBDEVICE_ID_CHASE_PCIFAST16FMC	0x0041
#define PCI_SUBVENDOR_ID_CHASE_PCIRAS		0x124D
#define PCI_SUBDEVICE_ID_CHASE_PCIRAS4		0xF001
#define PCI_SUBDEVICE_ID_CHASE_PCIRAS8		0xF010
#endif

#ifndef PCI_VENDOR_ID_QUATECH
#define PCI_VENDOR_ID_QUATECH		0x135C
#define PCI_DEVICE_ID_QUATECH_QSC100	0x0010
#define PCI_DEVICE_ID_QUATECH_DSC100	0x0020
#define PCI_DEVICE_ID_QUATECH_DSC200	0x0030
#define PCI_DEVICE_ID_QUATECH_QSC200	0x0040
#define PCI_DEVICE_ID_QUATECH_ESC100D	0x0050
#define PCI_DEVICE_ID_QUATECH_ESC100M	0x0060
#endif

#ifndef PCI_VENDOR_ID_ROCKWELL
#define PCI_VENDOR_ID_ROCKWELL		0x127A
#endif

#ifndef PCI_VENDOR_ID_USR
#define PCI_VENDOR_ID_USR		0x12B9
#endif

#ifndef PCI_SUBDEVICE_ID_SPECIALIX_SPEED4
#define PCI_SUBDEVICE_ID_SPECIALIX_SPEED4 0xa004
#endif

#ifndef PCI_VENDOR_ID_OXSEMI
#define PCI_VENDOR_ID_OXSEMI            0x1415
#define PCI_DEVICE_ID_OXSEMI_16PCI954   0x9501
#endif

#ifndef PCI_VENDOR_ID_LAVA
#define PCI_VENDOR_ID_LAVA		0x1407
#endif

#ifndef PCI_DEVICE_ID_LAVA_DUAL_SERIAL
#define PCI_DEVICE_ID_LAVA_DUAL_SERIAL	0x0100
#endif

#ifndef PCI_VENDOR_ID_TIMEDIA
#define PCI_VENDOR_ID_TIMEDIA		0x1409
#define PCI_DEVICE_ID_TIMEDIA_1889	0x7168
#endif 

#ifndef PCI_VENDOR_ID_SIIG
#define PCI_VENDOR_ID_SIIG		0x131f
#endif

#ifndef PCI_DEVICE_ID_SIIG_1S_10x_550
#define PCI_DEVICE_ID_SIIG_1S_10x_550  0x1000
#define PCI_DEVICE_ID_SIIG_1S_10x_650  0x1001
#define PCI_DEVICE_ID_SIIG_1S_10x_850  0x1002
#define PCI_DEVICE_ID_SIIG_2S_10x_550  0x1030
#define PCI_DEVICE_ID_SIIG_2S_10x_650  0x1031
#define PCI_DEVICE_ID_SIIG_2S_10x_850  0x1032
#define PCI_DEVICE_ID_SIIG_4S_10x_550  0x1050
#define PCI_DEVICE_ID_SIIG_4S_10x_650  0x1051
#define PCI_DEVICE_ID_SIIG_4S_10x_850  0x1052
#define PCI_DEVICE_ID_SIIG_1S_20x_550  0x2000
#define PCI_DEVICE_ID_SIIG_1S_20x_650  0x2001
#define PCI_DEVICE_ID_SIIG_1S_20x_850  0x2002
#define PCI_DEVICE_ID_SIIG_2S_20x_550  0x2030
#define PCI_DEVICE_ID_SIIG_2S_20x_650  0x2031
#define PCI_DEVICE_ID_SIIG_2S_20x_850  0x2032
#define PCI_DEVICE_ID_SIIG_4S_20x_550  0x2050
#define PCI_DEVICE_ID_SIIG_4S_20x_650  0x2051
#define PCI_DEVICE_ID_SIIG_4S_20x_850  0x2052
#define PCI_DEVICE_ID_SIIG_1S1P_10x_550	0x1010
#define PCI_DEVICE_ID_SIIG_1S1P_10x_650	0x1011
#define PCI_DEVICE_ID_SIIG_1S1P_10x_850	0x1012
#define PCI_DEVICE_ID_SIIG_2S1P_10x_550	0x1034
#define PCI_DEVICE_ID_SIIG_2S1P_10x_650	0x1035
#define PCI_DEVICE_ID_SIIG_2S1P_10x_850	0x1036
#define PCI_DEVICE_ID_SIIG_2P1S_20x_550	0x2040
#define PCI_DEVICE_ID_SIIG_2P1S_20x_650	0x2041
#define PCI_DEVICE_ID_SIIG_2P1S_20x_850	0x2042
#define PCI_DEVICE_ID_SIIG_1S1P_20x_550	0x2010
#define PCI_DEVICE_ID_SIIG_1S1P_20x_650	0x2011
#define PCI_DEVICE_ID_SIIG_1S1P_20x_850	0x2012
#define PCI_DEVICE_ID_SIIG_2S1P_20x_550	0x2060
#define PCI_DEVICE_ID_SIIG_2S1P_20x_650	0x2061
#define PCI_DEVICE_ID_SIIG_2S1P_20x_850	0x2062
#endif

#ifndef PCI_VENDOR_ID_COMPUTONE
#define PCI_VENDOR_ID_COMPUTONE			0x8e0e
#endif

#ifndef PCI_DEVICE_ID_COMPUTONE_PG
#define PCI_DEVICE_ID_COMPUTONE_PG		0x0302
#define PCI_SUBVENDOR_ID_COMPUTONE		0x8e0e
#define PCI_SUBDEVICE_ID_COMPUTONE_PG4	0x0001
#define PCI_SUBDEVICE_ID_COMPUTONE_PG8	0x0002
#define PCI_SUBDEVICE_ID_COMPUTONE_PG6	0x0003
#endif
